function [F12, A1, F21, A2] = disk2disk(r1, r2, h)
%[F12, A1, F21, A2] = disk2disk(r1, r2, h)
%
%  Description:
%
%    View factor between two coaxial disks.
%
%  Inputs:
%
%    r1 = radius of upper disk
%    r2 = radius of lower disk
%    h  = distance between the disks
%
%  Outputs:
%
%    F12 = view factor from upper disk to lower disk
%    A1  = area of the upper disk
%    F21 = viewfactor from lower disk to upper disk
%    A2  = area of the lower disk
%
%  Reference:
%
%    A Catalog of Radiation Heat Transfer Configuration Factors,
%    third edition, John R. Howell, The University of Texas at Austin
%
%      http://www.thermalradiation.net/sectionc/C-41.html
%
%==========================================================================

R1 = r1/h;
R2 = r2/h;
X = 1.0 + (1.0 + R2^2)/(R1^2);

A1 = pi*r1^2;  %  Upper disk area
A2 = pi*r2^2;  %  Lower disk area

F12 = (X - sqrt(X^2 - 4.0*(R2/R1)^2))/2.0;

F21 = F12*A1/A2;  %  F12*A1 = F21*A2
